<?php
    /*
    Plugin Name: The Slide by SimpleReach
    Plugin URI: https://www.simplereach.com
    Description: After installation, you must click '<a href='options-general.php?page=SimpleReach-Slide'>Settings &rarr; SimpleReach Slide</a>' to turn on The Slide.
    Version: 0.4.7
    Author: SimpleReach
    Author URI: https://www.simplereach.com
    */

require_once('srslide_functions.php');
require_once('srslide_post.php');

/**
 * Insert The Slide by SimpleReach onto the post page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param String $content the_content() output
 * @return String The content and The Slide code (if applicable)
 */
function srslide_insert_slide($content)
{
    global $post;
    $post_id = $post;
    if (is_object($post_id)) {
        $post_id = $post_id->ID;
    }

    // Return the content on anything other than post pages
    if (!is_single()) {
        return $content;
    }

    // If the post isn't published yet, we don't need a slide
    if ($post->post_status != 'publish') {
        return $content;
    }

    $sr_pub_id = get_option('srslide_pid');

    // There is no point in continuing without a PID, so stop
    if (strlen($sr_pub_id) != 24) {
        return $content;
    }


    $title = get_sr_post_title($post);
    $tags = get_sr_post_tags($post);
    $disable_on_post = get_post_meta($post_id,'_srslide_disable_on_post',true);
    $published_date = $post->post_date_gmt;
    $canonical_url = urlencode(get_permalink($post->ID));
    $slide_logo = get_option('srslide_show_logo') ? 'true' : 'false';
    $header_text = get_option('srslide_header_text');

    // Return the content and don't slide if we have no PID/bad PID
    if (isset($sr_pub_id) && strlen($sr_pub_id) != 24) {
        return $content;
    }

    // Ensure The Slide is enabled when it's supposed to be
    if (isset($disable_on_post) && $disable_on_post != true) {
        $disable_on_post = 'false';
    }

    // Get the JS ready to go
    $rv = "<!-- SimpleReach Slide Plugin Version: ". sr_plugin_version() ." -->\n";
    $rv .= "<script type='text/javascript' id='simplereach-slide-tag'>\n";
    $rv .= "  __spr_config = {\n";
    $rv .= "    pid: '$sr_pub_id',\n";
    $rv .= "    title: '$title',\n";
    $rv .= "    ckw: '$tags',\n";
    $rv .= "    no_slide: $disable_on_post,\n";
    $rv .= "    slide_logo: $slide_logo,\n";
    $rv .= "    pub: '$published_date',\n";
    $rv .= "    url: '$canonical_url',\n";
    $rv .= "    header: '$header_text'\n";
    $rv .= "  };\n";
    $rv .= "  var content = document.getElementById('simplereach-slide-tag').parentNode, loc;\n";
    $rv .= "  if (content.className){ loc = '.' + content.className; }\n";
    $rv .= "  if (content.id){ loc = '#' + content.id; }\n";
    $rv .= "  __spr_config.loc = loc || content;\n";
    $rv .= "  (function(){\n";
    $rv .= "    var s = document.createElement('script');\n";
    $rv .= "    s.async = true;\n";
    $rv .= "    s.type = 'text/javascript';\n";
    $rv .= "    s.src = document.location.protocol + '//d8rk54i4mohrb.cloudfront.net/js/slide.js';\n";
    $rv .= "    __spr_config.css = document.location.protocol + '//d8rk54i4mohrb.cloudfront.net/css/p/$sr_pub_id.css';\n";
    $rv .= "    (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(s);\n";
    $rv .= "  })();\n";

    $rv .= "</script>";

    return $content . $rv;
}
add_filter('the_content', 'srslide_insert_slide');

/**
 * Add the SimpleReach admin section
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_admin()
{
    include_once('srslide_admin.php');
}

/**
 * Add the SimpleReach admin options to the post CRUD page
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_admin_actions()
{
    include_once('srslide_post.php');
    add_options_page("SimpleReach Slide", "SimpleReach Slide", 1, "SimpleReach-Slide", "srslide_admin");
}
add_action('admin_menu','srslide_admin_actions');

add_action('add_meta_boxes','srslide_post_meta_box');

add_action('save_post','srslide_post_save_data');
add_action('edit_post','srslide_post_save_data');

/**
 * Ensure that we don't show The Slide on single pages
 *
 * @author Eric Lubow <elubow@simplereach.com>
 * @param None
 * @return None
 */
function srslide_header()
{
    if ( !is_single() ) {
        return;
    }
}
add_action('wp_head', 'srslide_header');

?>
