<?php
    /*
     * Part of the conditional for handling options updates
     */
    if($_POST['srslide_save_hidden'] == 'Y') {
        $errors = array();

        // Set the show logo option
        ($_POST['srslide_show_logo'] == 'on') ? update_option('srslide_show_logo',true) : update_option('srslide_show_logo',false);

        $header_length = strlen($_POST['srslide_header_text']);

        if ($header_length < 1 or $header_length > 30) {
            array_push($errors, "Header text cannot be more than 30 characters.");
        } else {
            update_option('srslide_header_text', strtoupper($_POST['srslide_header_text']) );
        }

        // Convert the style settings into a hash and save it
        $style_hash = create_style_hash($_POST);
        update_option('srslide_styles',$style_hash);
        $style_error = update_slide_styles();
        if ($style_error != "OK") {
            array_push($errors, $style_error);
        }

        // Save if we are error free or print the errors
        if (count($errors) == 0) {
          ?>
          <div class="updated"><p><strong><?php _e('Options saved. If you shifted The Slide position or adjusted the link color, it could take up to 15 minutes for your changes to take effect.'); ?></strong></p></div>
          <?php
        } else {
          ?>
          <div class="updated"><p><strong><?php _e('You have the following errors:'); ?></strong></p></div>

          <?php
              foreach ($errors as $i => $value) {
                  ?>
                  <div class="updated"><p style='margin-left:10px;'><strong><?php echo $value; ?></strong></p></div>
                  <?php
              }
        }

    /*
     * Part of the conditional for handling a registration
     */
    } else if ($_POST['srslide_register_hidden'] == 'Y') {

        // Setup the encoded params from the $_POST
        $encoded_params = '';
        foreach($_POST as $name => $value) {
            // Only pass vars that start with srslide_sr
            if (!preg_match('/^srslide_sr_.+/',$name)) { continue; }
            $encoded_params .= urlencode($name).'='.urlencode($value).'&';
        }

        // Get the blog name
        $encoded_params .= 'account_name='.urlencode(get_option('blogname')).'&';
        // Get the site URL
        $encoded_params .= 'website='.urlencode(get_option('siteurl')).'&';
        $encoded_params .= 'ts='.(int)gmdate('U').'&';

        // Remove the last '&'
        $encoded_params = substr($encoded_params, 0, strlen($encoded_params)-1);

        // Curl call for registration
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, "https://www.simplereach.com/publisher/wp_create");
        curl_setopt($curl, CURLOPT_POST, count(explode('&',$encoded_params)));
        curl_setopt($curl, CURLOPT_POSTFIELDS, $encoded_params);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $curl_resp = curl_exec($curl);
        curl_close($curl);

        // Decode the JSON
        $resp = json_decode($curl_resp);

        if ($resp->{'success'}) {

            // Save the PID to Wordpress
            update_option('srslide_pid',$resp->{'success'});

            // Set some defaults only now that we have a registration
            set_srslide_defaults($_POST);
            ?>
                <div id="message" class="updated below-h2"><p>
                    <?php _e('Congratulations, your SimpleReach account has been successfully created!') ?>
                </p></div>
            <?php
        } else {
            ?>
                <div id="message" class="updated below-h2"><p>
            <?php
                _e("We were not able to register you: ");
                if ($resp->{'error'} == 'Invalid Domain') {
                    _e("This domain has already been registered. Please contact <a href='mailto:support@simplereach.com'>SimpleReach support</a> if you believe you have received this message in error.");
                } else if ($resp->{'error'} == 'Incorrect Timestamp') {
                    _e("There was an error while you were attempting to register. Please try again or contact <a href='mailto:support@simplereach.com'>SimpleReach support</a> if you believe you have received this message in error.");
                } else if ($resp->{'error'} == 'Invalid Password') {
                    _e("The user name that you are attempting to register with already exists, but the password you entered was incorrect. Please try again or contact <a href='mailto:support@simplereach.com'>SimpleReach support</a> if you believe you have received this message in error.");
                } else {
                    _e("An unknown error has been encountered. Please try again or contact <a href='mailto:support@simplereach.com'>SimpleReach support</a>.");
                }
            ?>
                </p></div>
            <?php
            update_option('srslide_registered',false);
        }
    }

    // Is the publisher a registered SimpleReach user
    $sr_is_registered = get_option('srslide_registered');
?>

<div class="wrap">
    <?php echo "<h2>" . __( 'The Slide by SimpleReach', 'srslide_adminopt' ) . "</h2>"; ?>

    <?php if ($sr_is_registered) {
        // Part of our normal page display
        $srpid = get_option('srslide_pid');
        $srlogin = get_option('srslide_sr_login');
        $srslide_header_text = get_option('srslide_header_text');
        $srslide_style = get_option('srslide_styles');
        $debug_info = create_debug_info();

        $slide_show_logo = 'CHECKED=CHECKED';
        if (get_option('srslide_show_logo') == false) {
          $slide_show_logo = '';
        }
    ?>

        <div style="margin-left:10px;">
            <p>
                <?php _e("You're registered!"); ?>
            </p>
            <p>
                <?php _e("Use your email/password to LOG-IN to "); ?><a href="https://www.simplereach.com">simplereach.com</a> <?php _e(" to access your analytics/reporting dashboard"); ?>.
            </p>
            <p>
                <?php _e("If you have any questions, please don't hesitate to"); ?>
                <a href="https://www.simplereach.com/contact?r=support&e=<?php echo urlencode($srlogin); ?>&debug_info=<?php echo urlencode($debug_info); ?>#reach-out"><?php _e("contact us"); ?></a>!
            </p>
        </div>

      <hr />

        <?php echo "<h3>" . __('Display Settings', 'srslide_adminopt') . "</h3>"; ?>

        <div style='float:left;'>
            <form name="srslide_form" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">

                <input type="hidden" name="srslide_save_hidden" value="Y">

                <table border='0'>
                    <tr>
                        <td>
                            <div style='margin-bottom:40px;'><?php _e("Edit Header (Max 30 char):"); ?></div>
                        </td>
                        <td colspan='2'>
                            <div style='margin-bottom:20px;'>
                                <input style='width:220px;' type="textbox" name="srslide_header_text" value='<?php echo $srslide_header_text; ?>' /><br />
                                <span style='font-size:10px;'><?php _e("All letters will be uppercase."); ?> &nbsp; (<?php _e("Default: RECOMMENDED FOR YOU"); ?>)</span>
                            </div>
                        </td>
                    </tr>

                    <tr>
                        <td colspan='3'>
                            <div style='margin-bottom:10px;'>
                                <div style='margin-top:5px;float:left;width:80px;overflow:hidden;'><?php _e("Link Color:"); ?></div>
                                <?php
                                    $srslide_default_link_colors = array('#FE3F10', '#3B5998', '#CC0000');
                                    foreach ($srslide_default_link_colors as $color) {
                                ?>
                                    <div style='margin-top:7px;margin-left:5px;width:40px;overflow:hidden;float:left;'>
                                        <input type='radio' style='float:left;margin-top:3px;' name='srslide_style_link_color' value='<?php echo $color; ?>' <?php if ($srslide_style['link']['color'] == $color) { echo "CHECKED"; } ?>>
                                        <div style='border:1px solid;background-color:<?php echo $color; ?>;float:left;width:15px;height:15px;margin-left:5px;'></div>
                                    </div>
                                <?php
                                    }
                                ?>
                                    <input type='radio' name='srslide_style_link_color' value='other' <?php if (!in_array($srslide_style['link']['color'],$srslide_default_link_colors)) { echo "CHECKED"; } ?> style='margin-top:10px;float:left;margin-left:10px;'> &nbsp; <input style='margin-top:3px;width:60px;margin-left:-15px;' type="textbox" name="srslide_style_link_color_text" value='<?php if (!in_array($srslide_style['link']['color'],$srslide_default_link_colors)) { echo "{$srslide_style['link']['color']}"; } ?>' />
                                    <div style='margin-left:8px;font-size:12px;float:left;width:80px;overflow:hidden;line-height:16px;'><?php _e("hex code "); ?><br /><span style='font-size:10px;'><?php _e("(eg #FE3F10):"); ?></span></div>
                                </div>
                            </div>
                        </td>
                    </tr>

                    <tr>
                        <td colspan='3'>
                            <span style='line-height:50px;'><?php _e("Shift The Slide up by: "); ?></span>
                            <select name='srslide_style_element_bottom'>
                                <option value='0px' <?php if ($srslide_style['element']['bottom'] == '0px') { echo "SELECTED"; } ?>>0px</option>
                                <option value='30px' <?php if ($srslide_style['element']['bottom'] == '30px') { echo "SELECTED"; } ?>>30px</option>
                                <option value='40px' <?php if ($srslide_style['element']['bottom'] == '40px') { echo "SELECTED"; } ?>>40px</option>
                                <option value='50px' <?php if ($srslide_style['element']['bottom'] == '50px') { echo "SELECTED"; } ?>>50px</option>
                                <option value='60px' <?php if ($srslide_style['element']['bottom'] == '60px') { echo "SELECTED"; } ?>>60px</option>
                            </select>
                        </td>
                    </tr>

                    <tr>
                        <td colspan='3'>
                            <input type="checkbox" name="srslide_show_logo" <?php echo $slide_show_logo; ?> />
                            <span style='line-height:25px;'><?php _e("Display The Slide logo (increases engagement)"); ?></span>
                        </td>
                    </tr>
                </table>

                <input style="font-size:14px;margin-top:15px;padding:4px;" type="submit" name="Submit" value="<?php _e('Save', 'srslide_adminopt' ); ?>" />
            </form>
        </div>

        <div style='float:right;'>
            <img style='margin-bottom:25px;border:1px solid;' src='/wp-content/plugins/srslide_wordpress/screenshot-1.png'>
        </div>

    <?php
        } else {
        $slide_show_logo = 'CHECKED=CHECKED';
    ?>

        <p><strong><?php _e("Register for a SimpleReach account. If you have already registered at simplereach.com, enter your login information below.") ?></strong></p>
        <form name="srslide_form" method="post" action="<?php echo str_replace( '%7E', '~', $_SERVER['REQUEST_URI']); ?>">
          <input type="hidden" name="srslide_register_hidden" value="Y">

            <table style='border:0px;margin-top:20px;' cellspacing='8'>
              <tr>
                <td style="text-align:right;width:70px;"><?php _e("Email: " ); ?></td>
                <td><input type="text" name="srslide_sr_login" value="<?php echo $sr_login; ?>" size="35"></td>
                <td><?php _e(" ex: user@example.com" ); ?></td>
              </tr>

              <tr>
                <td style="text-align:right;width:70px;"><?php _e("Password: " ); ?></td>
                <td><input type="password" name="srslide_sr_pass" value="<?php echo $sr_password; ?>" size="35"></td>
                <td><?php _e(" ex: secretpass" ); ?></td>
              </tr>

              <tr>
                <td>&nbsp;</td>
                <td colspan='2' style='font-size:10px;'>
                  <input type="checkbox" name="srslide_show_logo" <?php echo $slide_show_logo; ?> />
                  <?php _e("I would like to display The Slide logo (increases engagement)"); ?>
                </td>
              </tr>

              <tr>
                <td>&nbsp;</td>
                <td style='text-align:right'><input style="font-size:14px;margin-top:10px;" type="submit" name="Submit" value="<?php _e('Register', 'srslide_adminopt' ); ?>" /></td>
                <td>&nbsp;</td>
              </tr>
            </table>

        </form>

    <?php } ?>
</div>
